import { AfterViewInit, ChangeDetectorRef, DoCheck, ElementRef, EventEmitter, NgZone, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import { MonacoEditorConfig, MonacoEditorOptions } from './monaco-editor-config';
import { MonacoProviderService } from './monaco-provider.service';
import { ResizeSensorService } from './resize-sensor.service';
/**
 * Wraps powerful Monaco Editor for simpilicity use in Angular.
 */
export declare abstract class MonacoCommonEditorComponent implements OnInit, OnChanges, AfterViewInit, OnDestroy, DoCheck, ControlValueAccessor {
    protected zone: NgZone;
    protected monacoEditorConfig: MonacoEditorConfig;
    protected monacoProvider: MonacoProviderService;
    protected cdr: ChangeDetectorRef;
    protected resizeSensor: ResizeSensorService;
    protected model: import('monaco-editor').editor.IModel;
    protected _value: string;
    protected _prevOptions: MonacoEditorOptions;
    protected destroyed: boolean;
    protected editor: import('monaco-editor').editor.IStandaloneCodeEditor;
    private relayoutFunction;
    private resizeSensorInstance;
    monacoLoaded: boolean;
    protected monacoContainer: ElementRef;
    protected monacoAnchor: ElementRef;
    /**
     * Raw Monaco editor options
     */
    options: import('monaco-editor').editor.IEditorConstructionOptions;
    /**
     * The URI which will be assigned to monaco-editor's model.
     * See monaco.Uri
     */
    modelUri: string;
    /**
     * Events emitted when monaco editor changed.
     */
    monacoEditorChanged: EventEmitter<{}>;
    /**
     * A helper ID to let the user to see the embedded monaco editor ID.
     *
     * E.g., you could use the following to get the embedded value of the editor.
     *     monaco.editor
     *      .getModels()
     *      .find(
     *        model =>
     *          model.id ===
     *          document.querySelector('aui-code-editor [model-id]').attributes[
     *            'model-id'
     *          ].value,
     *      )
     *      .getValue();
     */
    modelId: string;
    abstract createEditor(): import('monaco-editor').editor.IStandaloneCodeEditor;
    ngDoCheck(): void;
    constructor(zone: NgZone, monacoEditorConfig: MonacoEditorConfig, monacoProvider: MonacoProviderService, cdr: ChangeDetectorRef, resizeSensor: ResizeSensorService);
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnChanges({ modelUri }: SimpleChanges): void;
    ngOnDestroy(): void;
    dispose(): void;
    onChange: (_: string) => void;
    onTouched: () => void;
    writeValue(value: string): void;
    registerOnChange(fn: any): void;
    registerOnTouched(fn: any): void;
    createModel(value: string, uri?: string): import('monaco-editor').editor.ITextModel;
    private initEditor;
    private listenModelChanges;
    private updateEditorValue;
}
