import { MonacoEditorConfig, MonacoEditorOptions } from './monaco-editor-config';
/**
 * Provider for monaco editor.
 */
export declare class MonacoProviderService {
    private monacoEditorConfig;
    constructor(monacoEditorConfig: MonacoEditorConfig);
    private _theme;
    initMonaco(): Promise<any>;
    /**
     * Returns all available themes
     */
    readonly themes: string[];
    /**
     * Return the current theme
     */
    readonly theme: string;
    readonly isDarkTheme: boolean;
    toggleTheme(): void;
    /**
     * Expose global monaco object
     */
    readonly monaco: typeof import('monaco-editor');
    /**
     * Expose global requirejs function/object
     */
    readonly require: any;
    /**
     * Load additional monaco-editor modules.
     */
    loadModule(deps: string[]): Promise<{}>;
    changeTheme(theme: string): void;
    getEditorOptions(options: MonacoEditorOptions): MonacoEditorOptions;
    create(domElement: HTMLElement, options?: import('monaco-editor').editor.IEditorConstructionOptions): import('monaco-editor').editor.IStandaloneCodeEditor;
    createDiffEditor(domElement: HTMLElement, options?: import('monaco-editor').editor.IDiffEditorConstructionOptions): import('monaco-editor').editor.IStandaloneDiffEditor;
    colorizeElement(domElement: HTMLElement, options?: import('monaco-editor').editor.IColorizerElementOptions): import('monaco-editor').Promise<void, any>;
    getLanguageExtensionPoint(alias: string): import('monaco-editor').languages.ILanguageExtensionPoint;
    /**
     * Currently monaco-editor is loaded via its only loader and it is RequireJs (amd) spec:
     */
    protected configRequireJs(): Promise<any>;
    private defineThemes;
}
