import { ChangeDetectorRef, EventEmitter, OnDestroy, OnInit } from '@angular/core';
import { PaginatorIntl } from './paginator-intl';
/**
 * Change event object that is emitted when the user selects a
 * different page size or navigates to another page.
 */
export declare class PageEvent {
    /** The current page index. */
    pageIndex: number;
    /**
     * Index of the page that was selected previously.
     * @deletion-target 7.0.0 To be made into a required property.
     */
    previousPageIndex?: number;
    /** The current page size */
    pageSize: number;
    /** The current total number of items being paged */
    length: number;
}
export declare class PaginatorComponent implements OnInit, OnDestroy {
    intl: PaginatorIntl;
    private cdr;
    private _initialized;
    private _intlChanges;
    /** The zero-based page index of the displayed list of items. Defaulted to 0. */
    pageIndex: number;
    _pageIndex: number;
    /** The length of the total number of items that are being paginated. Defaulted to 0. */
    length: number;
    _length: number;
    /** Number of items to display on a page. By default set to 20. */
    pageSize: number;
    _pageSize: number;
    /** Number of items to display on a page. By default set to 50. */
    pageSizeOptions: number[];
    _pageSizeOptions: number[];
    /** Whether to hide the page size selection UI from the user. */
    hidePageSize: boolean;
    _hidePageSize: boolean;
    /** Whether to show the first/last buttons UI to the user. */
    /** TODO: Not take effect for now. */
    showFirstLastButtons: boolean;
    _showFirstLastButtons: boolean;
    /** Event emitted when the paginator changes the page size or page index. */
    readonly page: EventEmitter<PageEvent>;
    _displayedPageSizeOptions: number[];
    readonly pages: number[];
    constructor(intl: PaginatorIntl, cdr: ChangeDetectorRef);
    ngOnInit(): void;
    ngOnDestroy(): void;
    previousPage(): void;
    nextPage(): void;
    setPage(page: number): void;
    getPageLength(): number;
    hasPreviousPage(): boolean;
    hasPage(page: number): boolean;
    hasNextPage(): boolean;
    changePageSize(pageSize: number): void;
    private updateDisplayedPageSizeOptions;
    private emitPageEvent;
    private createRange;
}
