import { AfterContentInit, AfterViewInit, ElementRef, EventEmitter, OnDestroy, QueryList } from '@angular/core';
import { BehaviorSubject, Observable, Subject } from 'rxjs';
import { CommonForm } from '../form/public-api';
import { TooltipDirective } from '../tooltip/public-api';
import { ComponentSize } from '../types';
import { OptionComponent } from './option/option.component';
import { OptionFilterFn, TrackFn } from './select.types';
export declare abstract class BaseSelect<T> extends CommonForm<T> implements AfterContentInit, AfterViewInit, OnDestroy {
    size: ComponentSize;
    loading: boolean;
    placeholder: string;
    filterable: boolean;
    clearable: boolean;
    filterFn: (filterString: string, option: {
        label: string;
        value: any;
    }) => any;
    trackFn: (value: any) => any;
    allowCreate: boolean;
    defaultFirstOption: boolean;
    filterChange: EventEmitter<string>;
    show: EventEmitter<void>;
    hide: EventEmitter<void>;
    protected selectRef: ElementRef;
    protected tooltipRef: TooltipDirective;
    protected optionListRef: ElementRef;
    protected inputingOption: OptionComponent;
    customOptions: QueryList<OptionComponent>;
    contentOptions: QueryList<OptionComponent>;
    /**
     * Utility field to make sure the users always see the value as type array
     */
    abstract readonly values$: Observable<any[]>;
    readonly allOptions: any[];
    allOptions$: Observable<OptionComponent[]>;
    private _size;
    private _filterable;
    private _clearable;
    private _filterString;
    private _allowCreate;
    private filterString$$;
    private filterFn$$;
    private trackFn$$;
    protected focusedOption: OptionComponent;
    protected size$$: BehaviorSubject<ComponentSize>;
    protected destroy$$: Subject<void>;
    size$: Observable<ComponentSize>;
    trackFn$: Observable<TrackFn>;
    filterString$: Observable<string>;
    filterFn$: Observable<OptionFilterFn>;
    hasVisableOption$: Observable<boolean>;
    hasMatchedOption$: Observable<boolean>;
    customCreatedValues$: Observable<string[]>;
    containerWidth: string;
    readonly opened: boolean;
    readonly inputReadonly: boolean;
    filterString: string;
    ngAfterContentInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    openOption(): void;
    closeOption(): void;
    onShowOptions(): void;
    onHideOptions(): void;
    onInput(event: Event): void;
    onKeyDown(event: KeyboardEvent): void;
    onOptionClick(option: OptionComponent): void;
    protected autoFocusFirstOption(): void;
    protected focusOptionDir(dir: 'down' | 'up'): void;
    protected resetFocusedOption(focusedOption?: OptionComponent): void;
    protected scrollToOption(option: OptionComponent): void;
    protected selectFocusedOption(): void;
    protected escSelect(): void;
    private _filterFn;
    private _trackFn;
    abstract selectOption(option: OptionComponent): void;
    abstract clearValue(event: Event): void;
}
