import { TemplatePortal } from '@angular/cdk/portal';
import { EventEmitter, OnChanges, OnDestroy, OnInit, SimpleChanges, TemplateRef, ViewContainerRef } from '@angular/core';
import { Subject } from 'rxjs';
import { TabLabelDirective } from './tab-directives';
export declare class TabComponent implements OnInit, OnDestroy, OnChanges {
    private _viewContainerRef;
    /** Plain text label for the tab, used when there is no template label. */
    textLabel: string;
    /** Whether or not to show the close button in the header */
    closeable: boolean;
    /** Whether or not the tab is disabled  */
    disabled: any;
    close: EventEmitter<void>;
    /** Content for the tab label given by `<ng-template [auiTabLabel]>`. */
    templateLabel: TabLabelDirective;
    /** Template inside the AuiTab view that contains an `<ng-content>`. */
    _implicitContent: TemplateRef<any>;
    readonly content: TemplatePortal | null;
    /**
     * Whether the tab is currently active.
     */
    isActive: boolean;
    /**
     * The relatively indexed position where 0 represents the center, negative is left, and positive
     * represents the right.
     */
    position: number | null;
    /**
     * The initial relatively index origin of the tab if it was created and selected after there
     * was already a selected tab. Provides context of what position the tab should originate from.
     */
    origin: number | null;
    /** Emits whenever the label changes. */
    readonly _labelChange: Subject<void>;
    /** Emits whenever the disable changes */
    readonly _disableChange: Subject<void>;
    /** Emits whenever the closeable changes */
    readonly _closeableChange: Subject<void>;
    /** Portal that will be the hosted content of the tab */
    private _contentPortal;
    private _disabled;
    constructor(_viewContainerRef: ViewContainerRef);
    ngOnInit(): void;
    ngOnDestroy(): void;
    ngOnChanges(changes: SimpleChanges): void;
}
