/**
 * Message: lightweight toast
 * Alert: Heavyweight toast
 * Detailed comparison documents: http://confluence.alaudatech.com/pages/viewpage.action?pageId=23383163
 */
import { Overlay } from '@angular/cdk/overlay';
import { ApplicationRef, ComponentFactoryResolver, ComponentRef, Injector } from '@angular/core';
import { Toast } from './toast';
import { AlertContainerComponent } from './toast-container/alert-container.component';
import { AlertsWrapperComponent } from './toast-container/alerts-wrapper.component';
import { MessageContainerComponent } from './toast-container/message-container.component';
import { MessagesWrapperComponent } from './toast-container/messages-wrapper.component';
import { AlertOptions, ToastOptions } from './toast.types';
export interface ToastInstanceModel<T> {
    uniqueCert: {
        config: ToastOptions;
        type: 'message' | 'alert';
    };
    instance: T;
}
export declare class ToastService {
    private applicationRef;
    private injector;
    private cfr;
    private overlay;
    messageOverlayRef: ComponentRef<MessagesWrapperComponent>;
    alertsOverlayRef: ComponentRef<AlertsWrapperComponent>;
    toasts: Array<ToastInstanceModel<MessageContainerComponent | AlertContainerComponent>>;
    constructor(applicationRef: ApplicationRef, injector: Injector, cfr: ComponentFactoryResolver, overlay: Overlay);
    private initComponentRef;
    createMessage(toast: Toast<MessageContainerComponent>): Toast<MessageContainerComponent>;
    clearById(id: string): void;
    createAlert(toast: Toast<AlertContainerComponent>): Toast<AlertContainerComponent>;
    private parseOptions;
    messageSuccess(toastOptions: ToastOptions | string): Toast<MessageContainerComponent>;
    messageError(toastOptions: ToastOptions | string): Toast<MessageContainerComponent>;
    messageInfo(toastOptions: ToastOptions | string): Toast<MessageContainerComponent>;
    messageExplanation(toastOptions: ToastOptions | string): Toast<MessageContainerComponent>;
    messageWarning(toastOptions: ToastOptions | string): Toast<MessageContainerComponent>;
    alertSuccess(alertOptions: AlertOptions | string): Toast<AlertContainerComponent>;
    alertError(alertOptions: AlertOptions | string): Toast<AlertContainerComponent>;
    alertInfo(alertOptions: AlertOptions | string): Toast<AlertContainerComponent>;
    alertWarning(alertOptions: AlertOptions | string): Toast<AlertContainerComponent>;
    alertExplanation(alertOptions: AlertOptions | string): Toast<AlertContainerComponent>;
    closeAll(): void;
}
