import { Overlay, OverlayRef } from '@angular/cdk/overlay';
import { AfterViewInit, ChangeDetectorRef, ElementRef, EventEmitter, NgZone, OnDestroy, Renderer2, TemplateRef, ViewContainerRef } from '@angular/core';
import { Observable, ReplaySubject } from 'rxjs';
import { TooltipComponent } from './tooltip.component';
import { TooltipTrigger, TooltipType } from './tooltip.types';
export interface TooltipInterface {
    content: string | TemplateRef<any>;
    context: any;
    class: string;
    type: TooltipType;
    position: string;
    trigger: TooltipTrigger;
    disabled: boolean;
    hideOnClick: boolean;
    show: EventEmitter<void>;
    hide: EventEmitter<void>;
}
export declare class BaseTooltip implements TooltipInterface, AfterViewInit, OnDestroy {
    protected overlay: Overlay;
    protected viewContainerRef: ViewContainerRef;
    protected elRef: ElementRef;
    protected renderer: Renderer2;
    protected cdr: ChangeDetectorRef;
    protected ngZone: NgZone;
    static readonly DELAY_TIMES: number;
    content: string | TemplateRef<any>;
    context: any;
    class: string;
    type: TooltipType;
    position: string;
    trigger: TooltipTrigger;
    disabled: boolean;
    hideOnClick: boolean;
    show: EventEmitter<void>;
    hide: EventEmitter<void>;
    protected overlayRef: OverlayRef;
    protected componentIns: TooltipComponent;
    protected hostHovered: boolean;
    protected tooltipHovered: boolean;
    protected listeners: Array<() => void>;
    protected unlistenBody: () => void;
    protected inputContent$$: ReplaySubject<string | TemplateRef<any>>;
    protected inputType$$: ReplaySubject<TooltipType>;
    protected inputPosition$$: ReplaySubject<string>;
    protected inputClass$$: ReplaySubject<string>;
    protected inputContext$$: ReplaySubject<any>;
    protected tooltipChanged$: Observable<void>;
    protected _position: string;
    protected _trigger: TooltipTrigger;
    protected _disabled: boolean;
    readonly isCreated: boolean;
    constructor(overlay: Overlay, viewContainerRef: ViewContainerRef, elRef: ElementRef, renderer: Renderer2, cdr: ChangeDetectorRef, ngZone: NgZone);
    createTooltip(): void;
    disposeTooltip(): void;
    toggleTooltip(): void;
    updatePosition(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    protected updateListeners(): void;
    protected clearListeners(): void;
    protected createOverlay(): OverlayRef;
    protected onMouseEnter(): Promise<void>;
    protected onMouseLeave(): Promise<void>;
    protected onTooltipHovered(hovered: boolean): Promise<void>;
    protected onClick(): void;
    protected onBodyClick(event: Event): void;
    protected onFocus(): void;
    protected onBlur(): void;
}
